@@ -8,9 +8,12 @@
 #include <memory>
 #include <string>
 
+#include <boost/optional.hpp>
+
 #include <pbcopper/cli2/Tool.h>
 #include <pbcopper/cli2/internal/InterfaceData.h>
 #include <pbcopper/cli2/internal/OptionData.h>
+#include <pbcopper/logging/LogConfig.h>
 
 namespace PacBio {
 namespace CLI_v2 {
@@ -26,8 +29,8 @@ struct MultiToolInterfaceData
         : appName_{std::move(appName)}
         , appDescription_{std::move(appDescription)}
         , appVersion_{std::move(appVersion)}
-        , helpOption_{std::move(help)}
-        , versionOption_{std::move(versionOption)}
+        , helpOption_(std::move(help))              // icc 17 hack
+        , versionOption_(std::move(versionOption))  // icc 17 hack
     {
     }
 
@@ -40,6 +43,8 @@ struct MultiToolInterfaceData
     OptionData versionOption_;
 
     std::vector<Tool> tools_;
+
+    boost::optional<Logging::LogConfig> logConfig_;
 };
 
 }  // namespace internal
