@@ -11,10 +11,10 @@ set -vex
 meson \
   --werror \
   --buildtype "${BUILDTYPE:-release}" \
-  --default-library shared \
+  --default-library "${LIBRARYTYPE:-shared}" \
   --libdir lib \
   --unity "${ENABLED_UNITY_BUILD:-off}" \
-  --wrap-mode nofallback \
+  --wrap-mode "${ENABLED_WRAP_MODE:-nofallback}" \
   --prefix "${PREFIX_ARG:-/usr/local}" \
   -Db_coverage="${ENABLED_COVERAGE:-false}" \
   -Db_sanitize="${ENABLED_SANITIZERS:-none}" \
