@@ -4,18 +4,17 @@
 #include <iostream>
 #include <sstream>
 #include <string>
+#include <tuple>
 #include <vector>
 
 #include <pbcopper/cli2/CLI.h>
 #include <pbcopper/cli2/Option.h>
 #include <pbcopper/cli2/PositionalArgument.h>
 #include <pbcopper/cli2/Results.h>
-#include <pbcopper/utility/Unused.h>
-
 #include <pbcopper/cli2/internal/HelpMetrics.h>
 #include <pbcopper/cli2/internal/InterfaceHelpPrinter.h>
+#include <pbcopper/utility/OStreamRedirect.h>
 
-#include "../../include/OStreamRedirector.h"
 #include "PbcopperTestData.h"
 
 // clang-format off
@@ -107,7 +106,6 @@ PacBio::CLI_v2::Interface MakeSummarizeInterface()
 
 int SummarizeRunner(const PacBio::CLI_v2::Results&)
 {
-    std::cerr << "SummarizeRunner\n";
     return EXIT_SUCCESS;
 }
 
@@ -127,8 +125,8 @@ TEST(CLI2_CLI, can_print_version)
     };
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const PacBio::CLI_v2::Interface i{"frobber", "Frob all the things", "v3.1"};
     const int result = PacBio::CLI_v2::Run(args, i, runner);
@@ -166,8 +164,8 @@ TEST(CLI2_CLI, can_print_help)
     };
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const PacBio::CLI_v2::Interface i{"frobber", "Frob all the things.", "v3.1"};
     const int result = PacBio::CLI_v2::Run(args, i, runner);
@@ -254,8 +252,8 @@ Typical workflow:
     };
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -295,8 +293,8 @@ Usage:
     };
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -335,8 +333,8 @@ TEST(CLI2_CLI, can_run_from_command_line_args)
     i.AddOption(MaxNumLines);
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i, runner);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -394,8 +392,8 @@ TEST(CLI2_CLI, correctly_interprets_implicit_empty_strings)
     });
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i, runner);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -414,8 +412,8 @@ TEST(CLI2_CLI, can_run_multitoolinterface_subtool_from_command_line_args)
     };
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -446,8 +444,8 @@ TEST(CLI2_CLI, can_fetch_default_log_level_and_log_file_from_results)
     const auto defaultLogLevel = i.DefaultLogLevel();
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     auto runner = [&defaultLogLevel](const PacBio::CLI_v2::Results& results)
     {
@@ -486,8 +484,8 @@ TEST(CLI2_CLI, can_fetch_overriden_default_log_level_from_results)
     i.DefaultLogLevel(defaultLogLevel);
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     auto runner = [&MaxNumLines, &defaultLogLevel](const PacBio::CLI_v2::Results& results)
     {
@@ -519,8 +517,8 @@ TEST(CLI2_CLI, can_fetch_log_level_from_results)
     PacBio::CLI_v2::Interface i{"frobber", "Frob all the things.", "v3.1"};
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i, runner);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -540,8 +538,8 @@ TEST(CLI2_CLI, can_fetch_log_file_from_results)
     PacBio::CLI_v2::Interface i{"frobber", "Frob all the things.", "v3.1"};
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i, runner);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -562,8 +560,8 @@ TEST(CLI2_CLI, verbosity_is_true_if_enabled_and_user_requested)
     i.EnableVerboseOption();
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i, runner);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -584,8 +582,8 @@ TEST(CLI2_CLI, verbosity_is_false_if_enabled_but_not_user_requested)
     i.EnableVerboseOption();
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i, runner);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -605,8 +603,8 @@ TEST(CLI2_CLI, verbosity_is_false_if_not_enabled)
     PacBio::CLI_v2::Interface i{"frobber", "Frob all the things.", "v3.1"};
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i, runner);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -625,8 +623,8 @@ TEST(CLI2_CLI, can_run_tool_with_optional_pos_args)
     i.AddPositionalArgument(CLI_v2_CLITests::Source);
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     const int result = PacBio::CLI_v2::Run(args, i, runner);
     EXPECT_EQ(EXIT_SUCCESS, result);
@@ -644,8 +642,8 @@ TEST(CLI2_CLI, no_throw_on_disabled_log_file_option_in_setup)
     i.DisableLogFileOption();
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     EXPECT_NO_THROW(PacBio::CLI_v2::Run(args, i, runner););
 }
@@ -662,10 +660,128 @@ TEST(CLI2_CLI, no_throw_on_disabled_log_level_option_in_setup)
     i.DisableLogLevelOption();
 
     std::ostringstream s;
-    tests::CoutRedirect redirect(s.rdbuf());
-    UNUSED(redirect);
+    PacBio::Utility::CoutRedirect redirect{s.rdbuf()};
+    std::ignore = redirect;
 
     EXPECT_NO_THROW(PacBio::CLI_v2::Run(args, i, runner););
 }
 
+TEST(CLI2_CLI, multitoolinterface_can_override_subtool_log_config)
+{
+    auto refineRunner = [](const PacBio::CLI_v2::Results& results) {
+        EXPECT_EQ(PacBio::Logging::LogLevel::DEBUG, results.LogLevel());
+        return EXIT_SUCCESS;
+    };
+
+    PacBio::CLI_v2::MultiToolInterface i{"isoseq3", "De Novo Transcript Reconstruction", "3.1.2"};
+    const auto& refineInterface = CLI_v2_CLITests::MakeRefineInterface();
+    i.AddTools({{"refine",    refineInterface,  refineRunner},
+                {"cluster",   CLI_v2_CLITests::MakeClusterInterface(),   &CLI_v2_CLITests::ClusterRunner},
+                {"polish",    CLI_v2_CLITests::MakePolishInterface(),    &CLI_v2_CLITests::PolishRunner},
+                {"summarize", CLI_v2_CLITests::MakeSummarizeInterface(), &CLI_v2_CLITests::SummarizeRunner}});
+
+    PacBio::Logging::LogConfig config{PacBio::Logging::LogLevel::DEBUG};
+    i.LogConfig(config);
+
+    EXPECT_EQ(PacBio::Logging::LogLevel::WARN, refineInterface.DefaultLogLevel());
+    EXPECT_EQ(PacBio::Logging::LogLevel::DEBUG, i.LogConfig()->Level);
+
+    const std::vector<std::string> args {
+        "isoseq3", "refine", "--test", "--count", "10"
+    };
+    const int result = PacBio::CLI_v2::Run(args, i);
+    EXPECT_EQ(EXIT_SUCCESS, result);
+}
+
+TEST(CLI2_CLI, command_line_log_level_overrides_interface_configs)
+{
+    auto refineRunner = [](const PacBio::CLI_v2::Results& results) {
+        EXPECT_EQ(PacBio::Logging::LogLevel::TRACE, results.LogLevel());
+        return EXIT_SUCCESS;
+    };
+
+    PacBio::CLI_v2::MultiToolInterface i{"isoseq3", "De Novo Transcript Reconstruction", "3.1.2"};
+    const auto& refineInterface = CLI_v2_CLITests::MakeRefineInterface();
+    i.AddTools({{"refine",    refineInterface,  refineRunner},
+                {"cluster",   CLI_v2_CLITests::MakeClusterInterface(),   &CLI_v2_CLITests::ClusterRunner},
+                {"polish",    CLI_v2_CLITests::MakePolishInterface(),    &CLI_v2_CLITests::PolishRunner},
+                {"summarize", CLI_v2_CLITests::MakeSummarizeInterface(), &CLI_v2_CLITests::SummarizeRunner}});
+
+    PacBio::Logging::LogConfig config{PacBio::Logging::LogLevel::DEBUG};
+    i.LogConfig(config);
+
+    EXPECT_EQ(PacBio::Logging::LogLevel::WARN, refineInterface.DefaultLogLevel());
+    EXPECT_EQ(PacBio::Logging::LogLevel::DEBUG, i.LogConfig()->Level);
+
+    const std::vector<std::string> args {
+        "isoseq3", "refine", "--test", "--count", "10", "--log-level", "TRACE"
+    };
+    const int result = PacBio::CLI_v2::Run(args, i);
+    EXPECT_EQ(EXIT_SUCCESS, result);
+}
+
+// TEST(CLI2_CLI, throws_if_missing_required_number_of_pos_args)
+// {
+//     const PacBio::CLI_v2::PositionalArgument In {
+//     R"({
+//         "name" : "in",
+//         "description" : "Input file.",
+//         "type" : "file"
+//     })"
+//     };
+
+//     const PacBio::CLI_v2::PositionalArgument Out {
+//     R"({
+//         "name" : "out",
+//         "description" : "Output file.",
+//         "type" : "file"
+//     })"
+//     };
+
+//     const PacBio::CLI_v2::PositionalArgument Report {
+//     R"({
+//         "name" : "report",
+//         "description" : "Report file.",
+//         "type" : "file"
+//     })"
+//     };
+
+//     auto runner = [](const PacBio::CLI_v2::Results& results) {
+//         std::ignore = results;
+//         return EXIT_SUCCESS;
+//     };
+
+//     PacBio::CLI_v2::Interface i {
+//         "frobber",
+//         "Frobb your files in a most delightful, nobbly way",
+//         "3.14"
+//     };
+//     i.AddPositionalArguments({In, Out, Report});
+
+//     try {
+//         const std::vector<std::string> args {"frobber", "in.file"};
+//         const auto result = PacBio::CLI_v2::Run(args, i, runner);
+
+//         std::ignore = result;
+//         ASSERT_FALSE("should not reach here");
+//     } catch (std::runtime_error& e) {
+//         const std::string msg{
+//             "[pbcopper] command line parser ERROR: requires 3 arguments, but 1 was provided\n"
+//         };
+//         EXPECT_EQ(msg, e.what());
+//     }
+//     try {
+//         const std::vector<std::string> args {"frobber", "in.file", "out.file"};
+//         const auto result = PacBio::CLI_v2::Run(args, i, runner);
+
+//         std::ignore = result;
+//         ASSERT_FALSE("should not reach here");
+//     } catch (std::runtime_error& e) {
+//         const std::string msg{
+//             "[pbcopper] command line parser ERROR: requires 3 arguments, but 2 were provided\n"
+//         };
+//         EXPECT_EQ(msg, e.what());
+//     }
+// }
+
 // clang-format on
