@@ -18,7 +18,7 @@ using PositionalArgument = PacBio::CLI_v2::PositionalArgument;
 namespace CLI_v2_CommandLineParserTests {
 namespace Options {
 
-static const Option TargetDirectory
+const Option TargetDirectory
 {
 R"({
     "names" : ["t", "target-dir"],
@@ -28,7 +28,7 @@ R"({
 })"
 };
 
-static const Option Force
+const Option Force
 {
 R"({
     "names" : ["f", "force"],
@@ -37,7 +37,7 @@ R"({
 })"
 };
 
-static const Option Progress
+const Option Progress
 {
 R"({
     "names" : ["p"],
@@ -46,7 +46,7 @@ R"({
 })"
 };
 
-static const Option DryRun
+const Option DryRun
 {
 R"({
     "names" : ["n", "no-op"],
@@ -55,7 +55,7 @@ R"({
 })"
 };
 
-static const Option Timeout
+const Option Timeout
 {
 R"({
     "names" : ["timeout"],
@@ -65,7 +65,7 @@ R"({
 })"
 };
 
-static const Option Delta
+const Option Delta
 {
 R"({
     "names" : ["delta"],
@@ -75,7 +75,7 @@ R"({
 })"
 };
 
-static const Option Ploidy
+const Option Ploidy
 {
 R"({
     "names" : ["ploidy"],
@@ -86,7 +86,7 @@ R"({
 })"
 };
 
-static const Option Element
+const Option Element
 {
 R"({
     "names" : ["e", "element"],
@@ -97,7 +97,7 @@ R"({
 })"
 };
 
-static const Option ToolContractOnly
+const Option ToolContractOnly
 {
 R"({
     "names" : ["tc-only"],
@@ -107,7 +107,7 @@ R"({
 })"
 };
 
-static const PositionalArgument Source
+const PositionalArgument Source
 {
 R"({
     "name" : "source",
@@ -116,7 +116,7 @@ R"({
 })"
 };
 
-static const PositionalArgument Dest
+const PositionalArgument Dest
 {
 R"({
     "name" : "dest",
@@ -731,4 +731,114 @@ TEST(CLI2_CommandLineParser, does_not_allow_negative_value_for_string_option)
     }
 }
 
+TEST(CLI2_CommandLineParser, can_interpret_numerics_with_suffix)
+{
+    const Option UIntOption{
+    R"({
+        "names" : ["x"],
+        "description" : "x",
+        "type" : "unsigned int",
+        "default" : 0
+    })"};
+    const Option IntOption{
+    R"({
+        "names" : ["yoink"],
+        "description" : "y",
+        "type" : "int",
+        "default" : 0
+    })"};
+    const Option FloatOption{
+    R"({
+        "names" : ["z"],
+        "description" : "z",
+        "type" : "float",
+        "default" : 0.0
+    })"};
+
+    Interface i {
+        "frobber",
+        "Frobb your files in a most delightful, nobbly way",
+        "3.14"
+    };
+    i.AddOption(UIntOption)
+     .AddOption(IntOption)
+     .AddOption(FloatOption);
+
+    const CommandLineParser parser{i};
+    const auto results = parser.Parse({
+        "frobber",
+        "-x", "42K",
+        "--yoink=300m",
+        "-z", "3.14G"
+    });
+
+    const uint64_t x = results[UIntOption];
+    const int64_t y = results[IntOption];
+    const double z = results[FloatOption];
+
+    EXPECT_EQ(x, 42'000);
+    EXPECT_EQ(y, 300'000'000);
+    EXPECT_EQ(z, 3'140'000'000);
+}
+
+TEST(CLI2_CommandLineParser, can_interpret_dash_option_value)
+{
+    const PacBio::CLI_v2::PositionalArgument Input {
+    R"({
+        "name" : "input",
+        "description" : "Input file(s)."
+    })"};
+
+    const PacBio::CLI_v2::PositionalArgument StatsFile {
+    R"({
+        "name" : "stats",
+        "description" : "Stats file."
+    })"};
+
+    const PacBio::CLI_v2::Option OutputPrefix {
+    R"({
+        "names" : ["o", "output"],
+        "description" : [
+            "Prefix of output filenames, '-' implies streaming. Streaming not supported ",
+            "with compression nor with split_barcodes"
+        ],
+        "type" : "string"
+    })"};
+
+    const PacBio::CLI_v2::Option CompressionLevel {
+    R"({
+        "names" : ["c"],
+        "description" : "Gzip compression level [1-9]",
+        "type" : "int",
+        "default" : 1
+    })"};
+
+    PacBio::CLI_v2::Interface i{"app", "desc", "0.0"};
+    i.DisableLogLevelOption()
+     .DisableLogFileOption()
+     .DisableNumThreadsOption();
+
+    i.AddPositionalArguments({Input, StatsFile});
+    i.AddOptionGroup("Options", {OutputPrefix, CompressionLevel});
+
+    const CommandLineParser parser{i};
+    const auto results = parser.Parse({
+        "app",
+        "input.bam",
+        "-o", "-",
+        "-c", "7",
+        "stats.txt"
+    });
+
+    const std::string inputFile = results[Input];
+    const std::string statsFile = results[StatsFile];
+    const std::string outputPrefix = results[OutputPrefix];
+    const int compressionLevel = results[CompressionLevel];
+
+    EXPECT_EQ("input.bam", inputFile);
+    EXPECT_EQ("stats.txt", statsFile);
+    EXPECT_EQ("-", outputPrefix);
+    EXPECT_EQ(7, compressionLevel);
+}
+
 // clang-format on
